@@ -512,7 +512,7 @@ fn fn_args() {
                     params: vec![Param {
                         span: DUMMY_SP,
                         decorators: vec![],
-                        pat: Pat::Ident(quote_ident!("force").into()),
+                        pat: quote_ident!("force").into(),
                     }
                     .fold_with(&mut marker(&[("force", mark1)]))],
                     type_params: Default::default(),
@@ -647,16 +647,12 @@ fn params_in_fn() {
                         Param {
                             span: DUMMY_SP,
                             decorators: Default::default(),
-                            pat: Pat::Ident(
-                                Ident::new("param".into(), DUMMY_SP.apply_mark(mark1)).into(),
-                            ),
+                            pat: Ident::new("param".into(), DUMMY_SP.apply_mark(mark1)).into(),
                         },
                         Param {
                             span: DUMMY_SP,
                             decorators: Default::default(),
-                            pat: Pat::Ident(
-                                Ident::new("param".into(), DUMMY_SP.apply_mark(mark2)).into(),
-                            ),
+                            pat: Ident::new("param".into(), DUMMY_SP.apply_mark(mark2)).into(),
                         },
                     ],
                     type_params: Default::default(),
