@@ -1,5 +1,4 @@
 function foo() {
     bar__2;
-    function bar__2() {
-    }
+    function bar__2() {}
 }
