@@ -1,12 +1,12 @@
 var o = "PASS";
 try {
     throw 0;
-} catch (o1) {
+} catch (o__2) {
     (function() {
-        function a() {
-            o1 = "FAIL";
+        function a__3() {
+            o__2 = "FAIL";
         }
-        a(), a();
+        a__3(), a__3();
     })();
 }
 console.log(o);
