@@ -2,6 +2,6 @@ import { Nullable } from 'nullable';
 import { SomeOther } from 'some';
 import { Another } from 'some';
 class A extends Nullable {
-    other__0: Nullable<Another>;
+    other: Nullable<Another>;
 }
 new A();
