@@ -6,8 +6,8 @@ use swc_ecma_transforms_base::resolver::ts_resolver;
 use swc_ecma_visit::{FoldWith, Visit, VisitWith};
 use testing::fixture;
 
-#[fixture("../swc_ecma_parser/tests/typescript/**/*.ts")]
-#[fixture("../swc_ecma_parser/tests/typescript/**/*.tsx")]
+#[fixture("../swc_ecma_parser/tests/**/*.ts")]
+#[fixture("../swc_ecma_parser/tests/**/*.tsx")]
 fn no_empty(input: PathBuf) {
     eprintln!("{}", input.display());
 
@@ -45,16 +45,6 @@ fn no_empty(input: PathBuf) {
 struct AssertNoEmptyCtxt;
 
 impl Visit for AssertNoEmptyCtxt {
-    fn visit_class_prop(&mut self, n: &ClassProp) {
-        if let PropName::Computed(key) = &n.key {
-            key.expr.visit_with(self);
-        }
-
-        n.value.visit_with(self);
-        n.type_ann.visit_with(self);
-        n.decorators.visit_with(self);
-    }
-
     fn visit_expr(&mut self, n: &Expr) {
         n.visit_children_with(self);
 
@@ -65,13 +55,6 @@ impl Visit for AssertNoEmptyCtxt {
         }
     }
 
-    fn visit_member_expr(&mut self, n: &MemberExpr) {
-        n.obj.visit_with(self);
-        if let MemberProp::Computed(c) = &n.prop {
-            c.visit_with(self);
-        }
-    }
-
     fn visit_pat(&mut self, n: &Pat) {
         n.visit_children_with(self);
 
@@ -82,12 +65,6 @@ impl Visit for AssertNoEmptyCtxt {
         }
     }
 
-    fn visit_super_prop_expr(&mut self, n: &SuperPropExpr) {
-        if let SuperProp::Computed(c) = &n.prop {
-            c.visit_with(self);
-        }
-    }
-
     fn visit_ts_getter_signature(&mut self, n: &TsGetterSignature) {
         if n.computed {
             n.key.visit_with(self);
